# This package is based on the tidyverse package, hence the copyright
# attribution to RStudio.

#' @keywords internal
"_PACKAGE"

#' @importFrom stats quantile
#' @importFrom evd fpot pgpd
#' @importFrom ggplot2 autoplot labs ggplot geom_line geom_segment
#' @importFrom ggplot2 geom_contour_filled geom_contour scale_fill_manual
#' @importFrom lookout mvscale
#' @export
ggplot2::autoplot
#' @export
lookout::mvscale
